@@ -109,9 +109,9 @@ filterExisting <- function(b, modelList) {
   
   b <- lapply(b, function(i) {
 
-    f <- formulaList[sapply(formulaList, function(x) all.vars_trans(x)[1] == i[1])]
+    f <- formulaList[sapply(formulaList, function(x) all_vars_trans(x)[1] == i[1])]
 
-    if(any(sapply(f, function(x) any(all.vars_trans(x)[-1] %in% i[2])))) NULL else i
+    if(any(sapply(f, function(x) any(all_vars_trans(x)[-1] %in% i[2])))) NULL else i
 
   } )
 
@@ -242,11 +242,11 @@ removeCerror <- function(b, modelList) {
 #
 #     amat <- amat[, colSums(amat) > 0]
 #
-#     formulaList <- formulaList[sapply(formulaList, function(x) which(all.vars_notrans(x)[1] == colnames(amat)))]
+#     formulaList <- formulaList[sapply(formulaList, function(x) which(all_vars_notrans(x)[1] == colnames(amat)))]
 #
-#     trans <- lapply(formulaList, all.vars_trans)
+#     trans <- lapply(formulaList, all_vars_trans)
 #
-#     notrans <- lapply(formulaList, all.vars_notrans)
+#     notrans <- lapply(formulaList, all_vars_notrans)
 #
 #     b <- lapply(rev(b), function(i) {
 #
@@ -324,7 +324,7 @@ reverseNonLin <- function(b, modelList, amat) {
 
     idx <- names(idx)
 
-    idm <- sapply(formulaList, function(i) all.vars_trans(i)[1] %in% idx)
+    idm <- sapply(formulaList, function(i) all_vars_trans(i)[1] %in% idx)
 
     idm <- idm[
 
@@ -360,7 +360,7 @@ reverseNonLin <- function(b, modelList, amat) {
 
     }
 
-    r <- sapply(formulaList, function(x) all.vars_trans(x)[1])
+    r <- sapply(formulaList, function(x) all_vars_trans(x)[1])
 
     b <- b[sapply(b, function(x) any(x[2] %in% r))]
 
